@@ -18,12 +18,6 @@ use util;
 use xargo::Home;
 use {cargo, xargo};
 
-#[cfg(feature = "dev")]
-fn profile() -> &'static str {
-    "debug"
-}
-
-#[cfg(not(feature = "dev"))]
 fn profile() -> &'static str {
     "release"
 }
@@ -194,14 +188,7 @@ version = "0.0.0"
                 XargoMode::Check => cmd.arg("check")
             };
 
-            match () {
-                #[cfg(feature = "dev")]
-                () => {}
-                #[cfg(not(feature = "dev"))]
-                () => {
-                    cmd.arg("--release");
-                }
-            }
+            cmd.arg("--release");
             cmd.arg("--manifest-path");
             cmd.arg(td.join("Cargo.toml"));
             cmd.args(&["--target", cmode.triple()]);
@@ -559,6 +546,11 @@ impl Blueprint {
                     "features".to_owned(),
                     Value::Array(vec![Value::String("mem".to_owned())]),
                 );
+                // reference compiler-builtins with `version = "*"`,
+                // the corresponding version of compiler_builtins matching the used std
+                // is selected because of the copied `Cargo.lock`-file from std.
+                cb.insert("version".to_owned(),
+                    Value::String("*".to_owned()));
                 cb.insert("stage".to_owned(), Value::Integer(1));
                 t.insert(
                     "compiler_builtins".to_owned(),
